<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CircleConcentric</name>
    <message>
        <location filename="../CircleConcentric.ui" line="+17"/>
        <source>Distance:</source>
        <translation>Distanza:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translation>Numero:</translation>
    </message>
    <message>
        <source>&amp;Concentric (Distance)</source>
        <translation type="obsolete">&amp;Concentrico (Distanza)</translation>
    </message>
    <message>
        <location filename="../CircleConcentricInit.js" line="+2"/>
        <source>&amp;Concentric (with Distance)</source>
        <translation>&amp;Concentrico (distanza)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw concentric circle</source>
        <translation>Disegna cerchio concentrico</translation>
    </message>
</context>
</TS>
